@@ -59,6 +59,7 @@ class KickstartCommand(KickstartObject):
     """The base class for all kickstart commands.  This is an abstract class."""
     removedKeywords = []
     removedAttrs = []
+    conflictingCommands = []
 
     def __init__(self, writePriority=0, *args, **kwargs):
         """Create a new KickstartCommand instance.  This method must be
@@ -187,6 +188,7 @@ class KickstartCommand(KickstartObject):
         warnings.warn("_setToObj has been renamed to set_to_obj.  The old name will be removed in a future release.", PendingDeprecationWarning, stacklevel=2)
         self.set_to_obj(namespace, obj)
 
+
 class DeprecatedCommand(KickstartCommand):
     """Specify that a command is deprecated and no longer has any function.
        Any command that is deprecated should be subclassed from this class,
@@ -412,6 +414,10 @@ class KickstartHandler(KickstartObject):
             self.commands[cmd].lineno = lineno
             self.commands[cmd].seen = True
 
+            # Check for conflicting commands.
+            conflicting_cmds = self.commands[cmd].conflictingCommands
+            self._checkConflictingCommands(cmd, conflicting_cmds, lineno=lineno)
+
             # The parser returns the data object that was modified.  This is either
             # the command handler object itself (a KickstartCommand object), or it's
             # a BaseData subclass instance that should be put into the command's
@@ -427,6 +433,23 @@ class KickstartHandler(KickstartObject):
 
             return obj
 
+    def _checkConflictingCommands(self, cmd, conflicting_cmds, lineno=None):
+        """Check for conflicting commands and raise an error."""
+        for conflicting_cmd in conflicting_cmds:
+            if conflicting_cmd not in self.commands:
+                continue
+
+            if self.commands[conflicting_cmd] is None:
+                continue
+
+            if not self.commands[conflicting_cmd].seen:
+                continue
+
+            raise KickstartParseError(
+                _("The %s and %s commands can't be used at the same time.")
+                % (cmd, conflicting_cmd), lineno=lineno
+            )
+
 
 class BaseHandler(KickstartHandler):
     """A base kickstart handler.
