@@ -54,11 +54,8 @@ class FC3_AutoPart(KickstartCommand):
                             Automatically create partitions -- a root (``/``) partition,
                             a swap partition, and an appropriate boot partition
                             for the architecture. On large enough drives, this
-                            will also create a /home partition.
-
-                            The ``autopart`` command can't be used with the logvol,
-                            part/partition, raid, reqpart, or volgroup in the same
-                            kickstart file.""", version=FC3)
+                            will also create a /home partition.""",
+                              version=FC3, conflicts=self.conflictingCommands)
 
 class F9_AutoPart(FC3_AutoPart):
     removedKeywords = FC3_AutoPart.removedKeywords
@@ -157,6 +154,7 @@ class F12_AutoPart(F9_AutoPart):
 class RHEL6_AutoPart(F12_AutoPart):
     removedKeywords = F12_AutoPart.removedKeywords
     removedAttrs = F12_AutoPart.removedAttrs
+    conflictingCommands = ["partition", "raid", "volgroup", "logvol"]
 
     def __init__(self, writePriority=100, *args, **kwargs):
         F12_AutoPart.__init__(self, writePriority=writePriority, *args, **kwargs)
@@ -183,37 +181,6 @@ class RHEL6_AutoPart(F12_AutoPart):
                         filesystem.""")
         return op
 
-    def parse(self, args):
-        # call the overriden command to do its job first
-        retval = F12_AutoPart.parse(self, args)
-
-        # Using autopart together with other partitioning command such as
-        # part/partition, raid, logvol or volgroup can lead to hard to debug
-        # behavior that might among other result into an unbootable system.
-        #
-        # Therefore if any of those commands is detected in the same kickstart
-        # together with autopart, an error is raised and installation is
-        # aborted.
-        conflicting_command = ""
-
-        # seen indicates that the corresponding
-        # command has been seen in kickstart
-        if self.handler.partition.seen:
-            conflicting_command = "part/partition"
-        elif self.handler.raid.seen:
-            conflicting_command = "raid"
-        elif self.handler.volgroup.seen:
-            conflicting_command = "volgroup"
-        elif self.handler.logvol.seen:
-            conflicting_command = "logvol"
-
-        if conflicting_command:
-            # allow for translation of the error message
-            errorMsg = _("The %s and autopart commands can't be used at the same time") % conflicting_command
-            raise KickstartParseError(errorMsg, lineno=self.lineno)
-        return retval
-
-
 class F16_AutoPart(F12_AutoPart):
     removedKeywords = F12_AutoPart.removedKeywords
     removedAttrs = F12_AutoPart.removedAttrs
@@ -333,42 +300,12 @@ class F18_AutoPart(F17_AutoPart):
         return op
 
 class F20_AutoPart(F18_AutoPart):
+    conflictingCommands = ["partition", "raid", "volgroup", "logvol"]
+
     def __init__(self, writePriority=100, *args, **kwargs):
         F18_AutoPart.__init__(self, writePriority=writePriority, *args, **kwargs)
         self.typeMap["thinp"] = AUTOPART_TYPE_LVM_THINP
 
-    def parse(self, args):
-        # call the overriden command to do its job first
-        retval = F18_AutoPart.parse(self, args)
-
-        # Using autopart together with other partitioning command such as
-        # part/partition, raid, logvol or volgroup can lead to hard to debug
-        # behavior that might among other result into an unbootable system.
-        #
-        # Therefore if any of those commands is detected in the same kickstart
-        # together with autopart, an error is raised and installation is
-        # aborted.
-        conflicting_command = ""
-
-        # seen indicates that the corresponding
-        # command has been seen in kickstart
-        if self.handler.partition.seen:
-            conflicting_command = "part/partition"
-        elif self.handler.raid.seen:
-            conflicting_command = "raid"
-        elif self.handler.volgroup.seen:
-            conflicting_command = "volgroup"
-        elif self.handler.logvol.seen:
-            conflicting_command = "logvol"
-        elif hasattr(self.handler, "mount") and self.handler.mount.seen:
-            conflicting_command = "mount"
-
-        if conflicting_command:
-            # allow for translation of the error message
-            errorMsg = _("The %s and autopart commands can't be used at the same time") % conflicting_command
-            raise KickstartParseError(errorMsg, lineno=self.lineno)
-        return retval
-
     def _getParser(self):
         "Only necessary for the type change documentation"
         op = F18_AutoPart._getParser(self)
@@ -425,22 +362,10 @@ class F21_AutoPart(F20_AutoPart):
         return retval
 
 class F23_AutoPart(F21_AutoPart):
-    def parse(self, args):
-        # call the overriden command to do its job first
-        retval = F21_AutoPart.parse(self, args)
-
-        conflicting_command = ""
-        if hasattr(self.handler, "reqpart") and self.handler.reqpart.seen:
-            conflicting_command = "reqpart"
-
-        if conflicting_command:
-            # allow for translation of the error message
-            errorMsg = _("The %s and autopart commands can't be used at the same time") % conflicting_command
-            raise KickstartParseError(errorMsg, lineno=self.lineno)
-
-        return retval
+    conflictingCommands = ["partition", "raid", "volgroup", "logvol", "reqpart"]
 
 class RHEL7_AutoPart(F21_AutoPart):
+    conflictingCommands = ["partition", "raid", "volgroup", "logvol", "reqpart"]
 
     def __init__(self, writePriority=100, *args, **kwargs):
         F21_AutoPart.__init__(self, writePriority=writePriority, *args, **kwargs)
@@ -466,21 +391,6 @@ class RHEL7_AutoPart(F21_AutoPart):
                         Do not create a /home partition.""")
         return op
 
-    def parse(self, args):
-        # call the overriden command to do its job first
-        retval = F21_AutoPart.parse(self, args)
-
-        conflicting_command = ""
-        if hasattr(self.handler, "reqpart") and self.handler.reqpart.seen:
-            conflicting_command = "reqpart"
-
-        if conflicting_command:
-            # allow for translation of the error message
-            errorMsg = _("The %s and autopart commands can't be used at the same time") % conflicting_command
-            raise KickstartParseError(errorMsg, lineno=self.lineno)
-
-        return retval
-
 class F26_AutoPart(F23_AutoPart):
     removedKeywords = F23_AutoPart.removedKeywords
     removedAttrs = F23_AutoPart.removedAttrs
