@@ -18,8 +18,8 @@
 # with the express permission of Red Hat, Inc.
 #
 from pykickstart.version import RHEL5, RHEL6, versionToLongString
-from pykickstart.version import FC3, FC4, F8, F12, F14, F15, F17, F18, F19, F21, F29
-from pykickstart.base import KickstartCommand
+from pykickstart.version import FC3, FC4, F8, F12, F14, F15, F17, F18, F19, F21, F29, F34, F39
+from pykickstart.base import KickstartCommand, RemovedCommand
 from pykickstart.errors import KickstartParseError
 from pykickstart.options import KSOptionParser, commaSplit
 
@@ -160,7 +160,12 @@ class FC3_Lilo(FC3_Bootloader):
     def _getParser(self):
         op = super(FC3_Lilo, self)._getParser()
         op.prog = "lilo"
-        op.description += "\n\n.. deprecated:: %s" % versionToLongString(FC4)
+        return op
+
+class FC4_Lilo(RemovedCommand, FC3_Lilo):
+    def _getParser(self):
+        op = FC3_Lilo._getParser(self)
+        op.description += "\n\n.. versionremoved:: %s" % versionToLongString(FC4)
         return op
 
 
@@ -275,9 +280,8 @@ class F15_Bootloader(F14_Bootloader):
                         If given, the password specified by ``--password=`` is
                         already encrypted and should be passed to the bootloader
                         configuration without additional modification.""")
-        op.add_argument("--md5pass", dest="_md5pass", version=F15, help="""
-                        If using GRUB, similar to ``--password=`` except the password
-                        should already be encrypted.""")
+        op.add_argument("--md5pass", dest="_md5pass", metavar="MD5PASS", version=F15,
+                        help="Alias for ``--password=MD5PASS --iscrypted``.")
         return op
 
     def parse(self, args):
@@ -401,9 +405,8 @@ class RHEL6_Bootloader(F12_Bootloader):
                         If given, the password specified by ``--password=`` is
                         already encrypted and should be passed to the bootloader
                         configuration without additional modification.""")
-        op.add_argument("--md5pass", dest="_md5pass", version=RHEL6, help="""
-                        If using GRUB, similar to ``--password=`` except the
-                        password should already be encrypted.""")
+        op.add_argument("--md5pass", dest="_md5pass", metavar="MD5PASS", version=RHEL6,
+                        help="Alias for ``--password=MD5PASS --iscrypted``.")
         return op
 
     def parse(self, args):
@@ -499,3 +502,52 @@ class F29_Bootloader(F21_Bootloader):
 
 class RHEL8_Bootloader(F29_Bootloader):
     pass
+
+class F34_Bootloader(F29_Bootloader):
+    removedKeywords = F29_Bootloader.removedKeywords
+    removedAttrs = F29_Bootloader.removedAttrs
+
+    def _getParser(self):
+        op = F29_Bootloader._getParser(self)
+        op.remove_argument("--upgrade", version=F34)
+        return op
+
+class RHEL9_Bootloader(F34_Bootloader):
+    pass
+
+class F39_Bootloader(F34_Bootloader):
+    removedKeywords = F34_Bootloader.removedKeywords
+    removedAttrs = F34_Bootloader.removedAttrs
+
+    def __init__(self, *args, **kwargs):
+        F34_Bootloader.__init__(self, *args, **kwargs)
+        self.sdboot = kwargs.get("sdboot", False)
+
+    def _getArgsAsStr(self):
+        if self.disabled:
+            return " --disabled"
+
+        ret = F21_Bootloader._getArgsAsStr(self)
+
+        if self.sdboot:
+            ret += " --sdboot"
+
+        return ret
+
+
+    def _getParser(self):
+        op = F34_Bootloader._getParser(self)
+        op.add_argument("--sdboot", action="store_true", default=False,
+                        version=F39, help="""
+                        Use systemd-boot as the bootloader instead of
+                        grub2. This option only works on EFI machines.""")
+        return op
+
+    def parse(self, args):
+        retval = F34_Bootloader.parse(self, args)
+
+        if self.sdboot and self.extlinux:
+            msg = _("Only one of --sdboot and --extlinux may be specified for bootloader command.")
+            raise KickstartParseError(msg, lineno=self.lineno)
+
+        return retval
