@@ -18,7 +18,7 @@
 # with the express permission of Red Hat, Inc.
 #
 from pykickstart.version import RHEL5, RHEL6, RHEL8, versionToLongString
-from pykickstart.version import FC3, FC4, F9, F11, F12, F14, F17, F18, F23, F29
+from pykickstart.version import FC3, FC4, F9, F11, F12, F14, F17, F18, F23, F29, F34
 from pykickstart.base import BaseData, KickstartCommand
 from pykickstart.errors import KickstartParseError, KickstartParseWarning
 from pykickstart.options import KSOptionParser, mountpoint
@@ -333,7 +333,7 @@ class FC3_Partition(KickstartCommand):
                             """, epilog="""
                             If partitioning fails for any reason, diagnostic
                             messages will appear on virtual console 3.""",
-                            version=FC3)
+                            version=FC3, conflicts=self.conflictingCommands)
         op.add_argument("mntpoint", metavar="<mntpoint>", type=mountpoint, nargs=1,
                         version=FC3, help="""
                         The ``<mntpoint>`` is where the partition will be mounted
@@ -556,6 +556,7 @@ class F12_Partition(F11_Partition):
 class RHEL6_Partition(F12_Partition):
     removedKeywords = F12_Partition.removedKeywords
     removedAttrs = F12_Partition.removedAttrs
+    conflictingCommands = ["autopart"]
 
     def _getParser(self):
         op = F12_Partition._getParser(self)
@@ -570,15 +571,6 @@ class RHEL6_Partition(F12_Partition):
                         """)
         return op
 
-    def parse(self, args):
-        # first call the overriden command
-        retval = F12_Partition.parse(self, args)
-        # the part command can't be used together with the autopart command
-        # due to the hard to debug behavior their combination introduces
-        if self.handler.autopart.seen:
-            errorMsg = _("The part/partition and autopart commands can't be used at the same time")
-            raise KickstartParseError(errorMsg, lineno=self.lineno)
-        return retval
 
 class F14_Partition(F12_Partition):
     removedKeywords = F12_Partition.removedKeywords
@@ -635,19 +627,11 @@ class F18_Partition(F17_Partition):
 class F20_Partition(F18_Partition):
     removedKeywords = F18_Partition.removedKeywords
     removedAttrs = F18_Partition.removedAttrs
+    conflictingCommands = ["autopart", "mount"]
 
     def parse(self, args):
         # first call the overriden command
         retval = F18_Partition.parse(self, args)
-        # the part command can't be used together with the autopart command
-        # due to the hard to debug behavior their combination introduces
-        if self.handler.autopart.seen:
-            errorMsg = _("The part/partition and autopart commands can't be used at the same time")
-            raise KickstartParseError(errorMsg, lineno=self.lineno)
-        # the same applies to the 'mount' command
-        if hasattr(self.handler, "mount") and self.handler.mount.seen:
-            errorMsg = _("The part/partition and mount commands can't be used at the same time")
-            raise KickstartParseError(errorMsg, lineno=self.lineno)
 
         # when using tmpfs, grow is not suported
         if retval.fstype == "tmpfs":
@@ -760,3 +744,35 @@ class RHEL8_Partition(F29_Partition):
 
                     Btrfs support was removed.""" % versionToLongString(RHEL8)
         return op
+
+class F34_Partition(F29_Partition):
+    removedKeywords = F29_Partition.removedKeywords
+    removedAttrs = F29_Partition.removedAttrs
+
+    def _getParser(self):
+        op = F29_Partition._getParser(self)
+        op.remove_argument("--active", version=F34)
+        return op
+
+
+class RHEL9_Partition(F34_Partition):
+    removedKeywords = F34_Partition.removedKeywords
+    removedAttrs = F34_Partition.removedAttrs
+
+    def parse(self, args):
+        retval = F34_Partition.parse(self, args)
+        if retval.mountpoint.startswith("btrfs.") or retval.fstype == "btrfs":
+            raise KickstartParseError(_("Btrfs file system is not supported"), lineno=self.lineno)
+        return retval
+
+    def _getParser(self):
+        "Only necessary for the type change documentation"
+        op = F34_Partition._getParser(self)
+        for action in op._actions:
+            if "--fstype" in action.option_strings:
+                action.help += """
+
+                    .. versionchanged:: %s
+
+                    Btrfs support was removed.""" % versionToLongString(RHEL8)
+        return op
