@@ -17,9 +17,10 @@
 # subject to the GNU General Public License and may only be used or replicated
 # with the express permission of Red Hat, Inc.
 #
+import warnings
 from pykickstart.version import FC3, FC6, F18
 from pykickstart.base import KickstartCommand
-from pykickstart.errors import KickstartParseError
+from pykickstart.errors import KickstartParseError, KickstartDeprecationWarning
 from pykickstart.options import KSOptionParser, commaSplit
 
 from pykickstart.i18n import _
@@ -154,7 +155,7 @@ class F18_Timezone(FC6_Timezone):
                         package to be automatically installed then use ``-chrony``
                         in package selection. For example::
 
-                        ``timezone --ntpservers=ntp.cesnet.cz,tik.nic.cz Europe/Prague``
+                        timezone --ntpservers=ntp.cesnet.cz,tik.nic.cz Europe/Prague
                         """)
         return op
 
@@ -252,7 +253,7 @@ class RHEL7_Timezone(F18_Timezone):
                         package to be automatically installed then use ``-chrony``
                         in package selection. For example::
 
-                        ``timezone --ntpservers=ntp.cesnet.cz,tik.nic.cz Europe/Prague``
+                        timezone --ntpservers=ntp.cesnet.cz,tik.nic.cz Europe/Prague
                         """)
         return op
 
@@ -290,6 +291,32 @@ class F25_Timezone(F23_Timezone):
         F23_Timezone.__init__(self, writePriority, *args, **kwargs)
         self.op = self._getParser()
 
+    def __str__(self):
+        retval = KickstartCommand.__str__(self)
+        args = self._getArgsAsStr()
+        if args:
+            retval += "# System timezone\n"
+            retval += "timezone" + args + "\n"
+
+        return retval
+
+    def _getArgsAsStr(self):
+        retval = ""
+
+        if self.timezone:
+            retval += " " + self.timezone
+
+        if self.isUtc:
+            retval += " --isUtc"
+
+        if self.nontp:
+            retval += " --nontp"
+
+        if self.ntpservers:
+            retval += " --ntpservers=" + ",".join(self.ntpservers)
+
+        return retval
+
     def _getParser(self):
         op = KSOptionParser(prog="timezone", description="""
                             This required command sets the system time zone to
@@ -327,7 +354,7 @@ class F25_Timezone(F23_Timezone):
                         package to be automatically installed then use ``-chrony``
                         in package selection. For example::
 
-                        ``timezone --ntpservers=ntp.cesnet.cz,tik.nic.cz Europe/Prague``
+                        timezone --ntpservers=ntp.cesnet.cz,tik.nic.cz Europe/Prague
                         """)
         return op
 
@@ -359,3 +386,60 @@ class F25_Timezone(F23_Timezone):
             raise KickstartParseError(msg, lineno=self.lineno)
 
         return self
+
+class F32_Timezone(F25_Timezone):
+
+    def __init__(self, writePriority=0, *args, **kwargs):
+        F25_Timezone.__init__(self, writePriority, *args, **kwargs)
+        self.op = self._getParser()
+
+    def _getArgsAsStr(self):
+        retval = ""
+
+        if self.timezone:
+            retval += " " + self.timezone
+
+        if self.isUtc:
+            retval += " --utc"
+
+        if self.nontp:
+            retval += " --nontp"
+
+        if self.ntpservers:
+            retval += " --ntpservers=" + ",".join(self.ntpservers)
+
+        return retval
+
+    def parse(self, args):
+        F25_Timezone.parse(self, args)
+
+        if "--isUtc" in args:
+            warnings.warn(_("The option --isUtc will be deprecated in future releases. Please "
+                            "modify your kickstart file to replace this option with its preferred "
+                            "alias --utc."),
+                          KickstartDeprecationWarning)
+
+        return self
+
+
+class F33_Timezone(F32_Timezone):
+
+    def __init__(self, writePriority=0, *args, **kwargs):
+        F32_Timezone.__init__(self, writePriority, *args, **kwargs)
+        self.op = self._getParser()
+
+    def parse(self, args):
+        F32_Timezone.parse(self, args)
+
+        if self.ntpservers:
+            warnings.warn(_("The option --ntpservers will be deprecated in future releases. Please "
+                            "modify your kickstart file to replace this option with "
+                            "timesource --ntp-server <server hostname> command invocation, "
+                            "one per NTP server."),
+                          KickstartDeprecationWarning)
+        if self.nontp:
+            warnings.warn(_("The option --nontp will be deprecated in future releases. Please "
+                            "modify your kickstart file to replace this option with "
+                            "timesource --ntp-disable command invocation."),
+                          KickstartDeprecationWarning)
+        return self
