@@ -98,9 +98,10 @@ F35 = 35000
 F36 = 36000
 F37 = 37000
 F38 = 38000
+F39 = 39000
 
 # This always points at the latest version and is the default.
-DEVEL = F38
+DEVEL = F39
 
 # A one-to-one mapping from string representations to version numbers.
 versionMap = {
@@ -112,6 +113,7 @@ versionMap = {
     "F24": F24, "F25": F25, "F26": F26, "F27": F27, "F28": F28,
     "F29": F29, "F30": F30, "F31": F31, "F32": F32, "F33": F33,
     "F34": F34, "F35": F35, "F36": F36, "F37": F37, "F38": F38,
+    "F39": F39,
     "RHEL3": RHEL3, "RHEL4": RHEL4, "RHEL5": RHEL5, "RHEL6": RHEL6,
     "RHEL7": RHEL7, "RHEL8": RHEL8, "RHEL9": RHEL9
 }
